pub enum StellarSdkError {
Show 29 variants
InvalidBase32Character {
at_position: usize,
},
InvalidStellarKeyEncoding,
InvalidStellarKeyEncodingLength,
InvalidStellarKeyEncodingVersion {
expected_version: char,
found_version: char,
},
InvalidStellarKeyChecksum {
expected: u16,
found: u16,
},
InvalidSignatureLength {
found_length: usize,
expected_length: usize,
},
PublicKeyCantVerify,
InvalidBase64Encoding(DecodeError),
TooManySignatures,
AssetCodeTooLong,
InvalidAssetCodeCharacter,
ExceedsMaximumLength {
requested_length: usize,
allowed_length: i32,
},
InvalidHexEncoding(FromHexError),
InvalidHashConversion,
NotApproximableAsFraction,
InvalidPrice,
InvalidTrustLineLimit,
InvalidAuthorizeFlag,
InvalidAmountString,
AmountOverflow,
AmountNegative,
AmountNonPositive,
InvalidBinaryLength {
found_length: usize,
expected_length: usize,
},
InvalidBalanceId,
EmptyClaimants,
InvalidSignerWeight,
CantWrapFeeBumpTransaction,
FetchError(FetchError),
DecodeError(Vec<u8>),
}Variants
InvalidBase32Character
InvalidStellarKeyEncoding
The encoding can be decoded but is not the canonical encoding of the underlying binary key
InvalidStellarKeyEncodingLength
The encoding has an invalid length
InvalidStellarKeyEncodingVersion
The initial version byte is invalid for this EncodableKey
InvalidStellarKeyChecksum
The checksum in the encoding is invaliid
InvalidSignatureLength
The signature has an invalid length
PublicKeyCantVerify
Verification for this public key failed
InvalidBase64Encoding(DecodeError)
The base64 encoding of the signature is invalid
TooManySignatures
The transaction envelope already has the maximal number of signatures (20)
AssetCodeTooLong
InvalidAssetCodeCharacter
ExceedsMaximumLength
InvalidHexEncoding(FromHexError)
InvalidHashConversion
NotApproximableAsFraction
InvalidPrice
InvalidTrustLineLimit
InvalidAuthorizeFlag
InvalidAmountString
AmountOverflow
AmountNegative
AmountNonPositive
InvalidBinaryLength
InvalidBalanceId
EmptyClaimants
InvalidSignerWeight
CantWrapFeeBumpTransaction
FetchError(FetchError)
DecodeError(Vec<u8>)